agentle.agents.whatsapp.models.whatsapp\_image\_message
=======================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_image_message

   
   .. rubric:: Classes

   .. autosummary::
   
      WhatsAppImageMessage
      WhatsAppMediaMessage
      WhatsAppMessageType
   